@@ -79,6 +79,7 @@ public:
     H5074,
     H5102,
     H5106,
+    HHCCJCY10,
     MUE4094RT,
     MOKOBEACON,
     MOKOBEACONXPRO,
@@ -89,6 +90,7 @@ public:
     SBCU,
     SBMS,
     SBMT,
+    SBOT,
     SBS1,
     SHT4X,
     SCD4X,
