@@ -32,6 +32,7 @@
 #include "devices/H5074_json.h"
 #include "devices/H5102_json.h"
 #include "devices/H5106_json.h"
+#include "devices/HHCCJCY10_json.h"
 #include "devices/HHCCJCY01HHCC_json.h"
 #include "devices/HHCCPOT002_json.h"
 #include "devices/IBS_THBP01B_json.h"
@@ -54,6 +55,7 @@
 #include "devices/SBCU_json.h"
 #include "devices/SBMS_json.h"
 #include "devices/SBMT_json.h"
+#include "devices/SBOT_json.h"
 #include "devices/SBS1_json.h"
 #include "devices/SHT4X_json.h"
 #include "devices/SCD4X_json.h"
@@ -120,6 +122,7 @@ const char* _devices[][2] = {
     {_H5074_json, _H5074_json_props},
     {_H5102_json, _H5102_json_props},
     {_H5106_json, _H5106_json_props},
+    {_HHCCJCY10_json, _HHCCJCY10_json_props},
     {_MUE4094RT_json, _MUE4094RT_json_props},
     {_Mokobeacon_json, _Mokobeacon_json_props},
     {_MBXPRO_json, _MBXPRO_json_props},
@@ -130,6 +133,7 @@ const char* _devices[][2] = {
     {_SBCU_json, _SBCU_json_props},
     {_SBMS_json, _SBMS_json_props},
     {_SBMT_json, _SBMT_json_props},
+    {_SBOT_json, _SBOT_json_props},
     {_SBS1_json, _SBS1_json_props},
     {_SHT4X_json, _SHT4X_json_props},
     {_SCD4X_json, _SCD4X_json_props},
